Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2156)

Unified Diff: android_webview/browser/hardware_renderer.h

Issue 2337913003: Fork cc::OutputSurface into cc::CompositorFrameSink. (Closed)
Patch Set: cfsfork: android-vulkan Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « android_webview/browser/compositor_frame_consumer.h ('k') | android_webview/browser/hardware_renderer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: android_webview/browser/hardware_renderer.h
diff --git a/android_webview/browser/hardware_renderer.h b/android_webview/browser/hardware_renderer.h
index 352dba45e11fea93896641574080ba55375b591f..f1f5e6ce8f1efb7710c6ab7f14feaed35492b67e 100644
--- a/android_webview/browser/hardware_renderer.h
+++ b/android_webview/browser/hardware_renderer.h
@@ -47,7 +47,7 @@ class HardwareRenderer : public cc::SurfaceFactoryClient {
void ReturnResourcesInChildFrame();
void ReturnResourcesToCompositor(const cc::ReturnedResourceArray& resources,
const CompositorID& compositor_id,
- uint32_t output_surface_id);
+ uint32_t compositor_frame_sink_id);
void AllocateSurface();
void DestroySurface();
@@ -74,9 +74,10 @@ class HardwareRenderer : public cc::SurfaceFactoryClient {
cc::SurfaceId child_id_;
CompositorID compositor_id_;
// HardwareRenderer guarantees resources are returned in the order of
- // output_surface_id, and resources for old output surfaces are dropped.
- uint32_t last_committed_output_surface_id_;
- uint32_t last_submitted_output_surface_id_;
+ // compositor_frame_sink_id, and resources for old output surfaces are
+ // dropped.
+ uint32_t last_committed_compositor_frame_sink_id_;
+ uint32_t last_submitted_compositor_frame_sink_id_;
DISALLOW_COPY_AND_ASSIGN(HardwareRenderer);
};
« no previous file with comments | « android_webview/browser/compositor_frame_consumer.h ('k') | android_webview/browser/hardware_renderer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698